######
MASAÏ 
######

|masai|, a framework for processing, analysing and modelling 
of solid state NMR spectra

:Version: 0.1

.. warning::

	|masai| is still experimental and under active development. 
	It is not mature nor stable. 
	Its current design is subject to major changes, reorganizations, bugs and crashes!!!.
	
	**Should I say? be patient as I expect a fully working version with the upcoming 0.2 release.**
	
	
What is |masai|?
==================

|masai| is a software written in python and partially in fortran.

It (will) provides a general framework for the processing, analysis and modelling 
of Solid State NMR spectra.

A *GUI* application allows users to make basic processing and fitting of NMR spectra
(for now limited to the Bruker format).

The *API* should also be accessible to be included in other programs.

Documentation
===============

For more information, have a look to the (under work!) web pages at 
`http://fernandezc.github.com/masai <http://fernandezc.github.com/masai>`_

Citing |masai|
===============

When using Masaï for your own work, and before a paper is published 
on this software, you are kindly requested to cite the program this way:

Christian Fernandez, |masai|: a framework for processing, analysing and modelling 
of solid state NMR spectra, 
`http://fernandezc.github.com/masai <http://fernandezc.github.com/masai>`_, 
version 0.1, Laboratoire Catalyse et Spectrochimie - ENSICAEN/Université de Caen/CNRS, 2012

.. |masai| replace:: **Masaï**